==> duckdb_0.3.2.tar.gz: duckdb/src/duckdb/amalgamation-16.cpp <==
#include "src/planner/binder/statement/bind_show.cpp"

#include "src/planner/binder/statement/bind_simple.cpp"

#include "src/planner/binder/statement/bind_summarize.cpp"

#include "src/planner/binder/statement/bind_update.cpp"

#include "src/planner/binder/statement/bind_vacuum.cpp"

#include "src/planner/binder/tableref/bind_basetableref.cpp"

#include "src/planner/binder/tableref/bind_crossproductref.cpp"

#include "src/planner/binder/tableref/bind_emptytableref.cpp"

#include "src/planner/binder/tableref/bind_expressionlistref.cpp"

#include "src/planner/binder/tableref/bind_joinref.cpp"

#include "src/planner/binder/tableref/bind_named_parameters.cpp"

#include "src/planner/binder/tableref/bind_subqueryref.cpp"

#include "src/planner/binder/tableref/bind_table_function.cpp"

#include "src/planner/binder/tableref/plan_basetableref.cpp"

#include "src/planner/binder/tableref/plan_crossproductref.cpp"

#include "src/planner/binder/tableref/plan_cteref.cpp"

#include "src/planner/binder/tableref/plan_dummytableref.cpp"

#include "src/planner/binder/tableref/plan_expressionlistref.cpp"

#include "src/planner/binder/tableref/plan_joinref.cpp"

#include "src/planner/binder/tableref/plan_subqueryref.cpp"

#include "src/planner/binder/tableref/plan_table_function.cpp"

#include "src/planner/expression.cpp"

#include "src/planner/expression/bound_aggregate_expression.cpp"

#include "src/planner/expression/bound_between_expression.cpp"

#include "src/planner/expression/bound_case_expression.cpp"

#include "src/planner/expression/bound_cast_expression.cpp"

#include "src/planner/expression/bound_columnref_expression.cpp"

#include "src/planner/expression/bound_comparison_expression.cpp"

#include "src/planner/expression/bound_conjunction_expression.cpp"

#include "src/planner/expression/bound_constant_expression.cpp"

#include "src/planner/expression/bound_function_expression.cpp"

#include "src/planner/expression/bound_operator_expression.cpp"

#include "src/planner/expression/bound_parameter_expression.cpp"

#include "src/planner/expression/bound_reference_expression.cpp"

#include "src/planner/expression/bound_subquery_expression.cpp"

#include "src/planner/expression/bound_unnest_expression.cpp"

#include "src/planner/expression/bound_window_expression.cpp"

#include "src/planner/expression_binder.cpp"

#include "src/planner/expression_binder/aggregate_binder.cpp"

#include "src/planner/expression_binder/alter_binder.cpp"

#include "src/planner/expression_binder/check_binder.cpp"

#include "src/planner/expression_binder/column_alias_binder.cpp"

#include "src/planner/expression_binder/constant_binder.cpp"

#include "src/planner/expression_binder/group_binder.cpp"

#include "src/planner/expression_binder/having_binder.cpp"

#include "src/planner/expression_binder/index_binder.cpp"

==> duckdb_0.3.4-1.tar.gz: duckdb/src/duckdb/amalgamation-16.cpp <==
#include "src/planner/binder/statement/bind_select.cpp"

#include "src/planner/binder/statement/bind_set.cpp"

#include "src/planner/binder/statement/bind_show.cpp"

#include "src/planner/binder/statement/bind_simple.cpp"

#include "src/planner/binder/statement/bind_summarize.cpp"

#include "src/planner/binder/statement/bind_update.cpp"

#include "src/planner/binder/statement/bind_vacuum.cpp"

#include "src/planner/binder/tableref/bind_basetableref.cpp"

#include "src/planner/binder/tableref/bind_crossproductref.cpp"

#include "src/planner/binder/tableref/bind_emptytableref.cpp"

#include "src/planner/binder/tableref/bind_expressionlistref.cpp"

#include "src/planner/binder/tableref/bind_joinref.cpp"

#include "src/planner/binder/tableref/bind_named_parameters.cpp"

#include "src/planner/binder/tableref/bind_subqueryref.cpp"

#include "src/planner/binder/tableref/bind_table_function.cpp"

#include "src/planner/binder/tableref/plan_basetableref.cpp"

#include "src/planner/binder/tableref/plan_crossproductref.cpp"

#include "src/planner/binder/tableref/plan_cteref.cpp"

#include "src/planner/binder/tableref/plan_dummytableref.cpp"

#include "src/planner/binder/tableref/plan_expressionlistref.cpp"

#include "src/planner/binder/tableref/plan_joinref.cpp"

#include "src/planner/binder/tableref/plan_subqueryref.cpp"

#include "src/planner/binder/tableref/plan_table_function.cpp"

#include "src/planner/bound_result_modifier.cpp"

#include "src/planner/expression.cpp"

#include "src/planner/expression/bound_aggregate_expression.cpp"

#include "src/planner/expression/bound_between_expression.cpp"

#include "src/planner/expression/bound_case_expression.cpp"

#include "src/planner/expression/bound_cast_expression.cpp"

#include "src/planner/expression/bound_columnref_expression.cpp"

#include "src/planner/expression/bound_comparison_expression.cpp"

#include "src/planner/expression/bound_conjunction_expression.cpp"

#include "src/planner/expression/bound_constant_expression.cpp"

#include "src/planner/expression/bound_function_expression.cpp"

#include "src/planner/expression/bound_operator_expression.cpp"

#include "src/planner/expression/bound_parameter_expression.cpp"

#include "src/planner/expression/bound_reference_expression.cpp"

#include "src/planner/expression/bound_subquery_expression.cpp"

#include "src/planner/expression/bound_unnest_expression.cpp"

#include "src/planner/expression/bound_window_expression.cpp"

#include "src/planner/expression_binder.cpp"

#include "src/planner/expression_binder/aggregate_binder.cpp"

#include "src/planner/expression_binder/alter_binder.cpp"

#include "src/planner/expression_binder/check_binder.cpp"

#include "src/planner/expression_binder/column_alias_binder.cpp"

#include "src/planner/expression_binder/constant_binder.cpp"

#include "src/planner/expression_binder/group_binder.cpp"
